
:autogenerated:

krotov.propagators module
=========================

.. currentmodule:: krotov.propagators

.. automodule:: krotov.propagators
    :members: expm
    :undoc-members:
    :show-inheritance:
    :member-order: bysource

    Summary
    -------

    Functions:

    .. autosummary::
        :nosignatures:

        expm





    ``__all__``: :func:`expm <krotov.propagators.expm>`



    Reference
    ---------